@@ -2,6 +2,7 @@ import re
 import warnings
 from cached_property import cached_property
 
+from .builtin_models import _fix_deprecated_builtin_models_and_warn
 from .card import Card
 from .util import guid_for
 
@@ -47,13 +48,14 @@ class _TagList(list):
 
 
 class Note:
-  _INVALID_HTML_TAG_RE = re.compile(r'<(?!/?[a-z0-9]+(?: .*|/?)>)(?:.|\n)*?>')
+  _INVALID_HTML_TAG_RE = re.compile(r'<(?!/?[a-zA-Z0-9]+(?: .*|/?)>)(?:.|\n)*?>')
 
-  def __init__(self, model=None, fields=None, sort_field=None, tags=None, guid=None):
+  def __init__(self, model=None, fields=None, sort_field=None, tags=None, guid=None, due=0):
     self.model = model
     self.fields = fields
     self.sort_field = sort_field
     self.tags = tags or []
+    self.due = due
     try:
       self.guid = guid
     except AttributeError:
@@ -147,6 +149,7 @@ class Note:
                       " your field data isn't already HTML-encoded: {}".format(' '.join(invalid_tags)))
 
   def write_to_db(self, cursor, timestamp: float, deck_id, id_gen):
+    self.fields = _fix_deprecated_builtin_models_and_warn(self.model, self.fields)
     self._check_number_model_fields_matches_num_fields()
     self._check_invalid_html_tags_in_fields()
     cursor.execute('INSERT INTO notes VALUES(?,?,?,?,?,?,?,?,?,?,?);', (
@@ -165,7 +168,7 @@ class Note:
 
     note_id = cursor.lastrowid
     for card in self.cards:
-      card.write_to_db(cursor, timestamp, deck_id, note_id, id_gen)
+      card.write_to_db(cursor, timestamp, deck_id, note_id, id_gen, self.due)
 
   def _format_fields(self):
     return '\x1f'.join(self.fields)
